import type { CfDeployConfigPromptOptions, CfDeployConfigQuestions, CfSystemChoice, CfDeployConfigAnswers, CfAppRouterDeployConfigPromptOptions, CfAppRouterDeployConfigQuestions } from './types';
import { promptNames, appRouterPromptNames, RouterModuleType } from './types';
import type { InquirerAdapter } from '@sap-ux/inquirer-common';
import type { Logger } from '@sap-ux/logger';
/**
 * Retrieves Cloud Foundry deployment configuration prompts.
 *
 * This function returns a list of cf deployment questions based on the provided application root and prompt options.
 *
 * @param {CfDeployConfigPromptOptions} promptOptions - The configuration options for prompting during cf target deployment.
 * @param logger - The logger instance to use for logging.
 * @returns {Promise<CfDeployConfigQuestions[]>} A promise that resolves to an array of questions for cf target prompting.
 */
declare function getPrompts(promptOptions: CfDeployConfigPromptOptions, logger?: Logger): Promise<CfDeployConfigQuestions[]>;
/**
 * Retrieves the application router configuration prompts.
 *
 * @param {CfDeployConfigPromptOptions} promptOptions - The options for configuring application router prompts.
 * @param {Logger} [logger] - An optional logger instance.
 * @returns {Promise<CfAppRouterDeployConfigQuestions[]>} A promise that resolves to an array of
 * application router deployment configuration questions.
 */
declare function getAppRouterPrompts(promptOptions: CfAppRouterDeployConfigPromptOptions, logger?: Logger): Promise<CfAppRouterDeployConfigQuestions[]>;
/**
 * Prompt for cf inquirer inputs.
 *
 * @param adapter - optionally provide references to a calling inquirer instance, this supports integration to Yeoman generators, for example
 * @param promptOptions - options that can control some of the prompt behavior. See {@link CfDeployConfigPromptOptions} for details
 * @param logger - logger instance to use for logging
 * @returns the prompt answers
 */
declare function prompt(adapter: InquirerAdapter, promptOptions: CfDeployConfigPromptOptions, logger?: Logger): Promise<CfDeployConfigAnswers>;
export { getPrompts, type CfDeployConfigPromptOptions, type CfSystemChoice, promptNames, prompt, appRouterPromptNames, getAppRouterPrompts, type CfAppRouterDeployConfigPromptOptions, RouterModuleType };
//# sourceMappingURL=index.d.ts.map